import { myRequest, BASE_URL } from '@/util/api.js'

// 上传图片
export const uploadUrl = BASE_URL+'common/upload'
//////////////////////////////////////////////////////////////////////////////////////////////////////////////
//首页  获取时间段
export function netTime(data) {
	return myRequest('common/getTimes',data)
}
//添加 日程
export function netAddSchedule(data) {
	return myRequest('event/addEvent',data)
}
//跟据时间  获取日程列表
export function netScheduleList(data) {
	return myRequest('event/getEvent',data)
}
//修改日程 状态
export function netEditScheculeStatus(data) {
	return myRequest('event/changeStatus',data)
}
//获取 待办 事项
export function netNeedDealtData() {
	return myRequest('index/agent')
}
//获取  待跟进  任务列表
export function netGetFollowList() {
	return myRequest('index/event_task')
}
//获取 待处理  日程列表
export function netGetScheList() {
	return myRequest('index/event_one')
}
//获取  待审核  合同 列表
export function netGetContractList() {
	return myRequest('index/examine_contract')
}
//获取  待审核   回款  列表
export function netGetPaymentList() {
	return myRequest('index/examine_receivables')
}
//获取  待回款  提醒 列表
export function netGetPaymentRemindList() {
	return myRequest('index/examine_receivables_plan')
}
//获取  出差  签到 列表
export function netGetSignList(data) {
	return myRequest('event/getSign',data)
}
//签到 详情
export function netGetSignDetail(data) {
	return myRequest('event/getSignDetail',data)
}
//添加 出差 签到
export function netAddSignin(data) {
	return myRequest('event/addSign',data)
}
//数据 看板  成交排行 数据 
export function netGetData(data) {
	return myRequest('statistics/contractRanding',data)
}
//数据 看板  机型排行  数据
export function netGetModalData(data) {
	return myRequest('statistics/contractRanking',data)
}
// 目标 完成 度
export function netTargetData(data) {
	return myRequest('statistics/staffAchievementStatistics',data)
}
//回款 数据 排名
export function netPaymentRank(data) {
	return myRequest('statistics/receivablesRanking',data)
}
//成交 数据  排行
export function netDealRank(data) {
	return myRequest('statistics/contractMoneyRanking',data)
}
//业绩  新增 总汇
export function netAddDataRank() {
	return myRequest('statistics/newRanking')
}

//客户新增  排行
export function netCustomerARank(data) {
	return myRequest('statistics/newCustomer',data)
}

//客户跟进 数量 排行
export function netCustomerFRank(data) {
	return myRequest('/statistics/newRecord',data)
}


/**
 * 业绩 新增  个人  团队  数据 
 * */
 //个人
 export function netPersonalData(data) {
	 return myRequest('statistics/newRanking',data)
 }
 //团队
 export function netTeamData(data) {
	 return myRequest('statistics/addCustomerStatistics',data)
 }
 
 
 
 
 
 
 

////////////////////////////////////////////////////////////////////////////////////////////
//获取 周围 客户
export function netNearKehuList(data) {
	return myRequest('customer/nearby',data)
}

/////////////////////////////////////////////////////////////////////////////////////////////
//获取个人基本信息
export function netGetUserInfo() {
	return myRequest('staff/getInfo')
}
//编辑 个人 信息
export function netEditUserInfo(data) {
	return myRequest('staff/editInfo',data)
}
//绑定 手机号
export function netBindPhone(data) {
	return myRequest('staff/use_phone',data)
}
//重点关注  客户列表
export function netGetKeyKehu(data) {
	return myRequest('customer/collectList',data)
}

//企业 信息
export function netCompanysInfo() {
	return myRequest('index/getCompanys')
}
//反馈 意见
export function netFeedBack(data) {
	return myRequest('index/feedback',data)
}
//用户  服务  协议
export function netServiceText(data) {
	return myRequest('index/serviceContent')
}

///////////////////////////////////////////////////////////////////////////////////////////////////
//表单设置  leads 线索 customer 客户 contacts 联系人 contract 合同 examine回款   business商机
export function netSetForm(data) {
	return myRequest('common/getForm',data)
}
//搜索条件   表单
export function netSearchForm(data) {
	return myRequest('common/getSearchFields',data)
}
////////////////////////////////////////////////////////////////////////////////////////////////////
/**
 * 员工 接口
 * */

//员工 列表
export function netStaffList(){
	return myRequest('staff/getStaffList')
}
//员工 详情 id
export function netStaffDetail(data){
	return myRequest('staff/getStaffDetail',data)
}
//员工 所属 客户列表 id
export function netStaffofCustomerList(data) {
	return myRequest('staff/getStaffCustomer',data)
}
//禁用帐号
export function netDisableAccount(data) {
	return myRequest('staff/disable_user',data)
}
//编辑员工
export function netEditStaff(data) {
	return myRequest('staff/updateStaff',data)
}
//获取部门 列表
export function netDepartmentList() {
	return myRequest('staff/getDepartment')
}
//获取  员工   业绩统计
export function netStaffAchievement(data) {
	return myRequest('staff/getStaffStatistics',data)
}

//获取 待审核  员工 列表
export function netExamineStaffList(data) {
	return myRequest('staff/getCheckStaffList',data)
}
//审核 员工  通过
export function netPassStaffInfo(data) {
	return myRequest('staff/checkStaffSuccess',data)
}
//审核 员工 拒绝
export function netRefuseStaffInfo(data) {
	return myRequest('staff/checkStaffError',data)
} 
//获取员工默认的提醒或审核人 customer客户  record 跟进 contract 合同 
// consume 费用 receivables 回款  approval':'工作报告'
export function netStaffDefaultReviewer(data) {
	return myRequest('staff/getStaffIds',data)
}

///////////////////////////////////////////////////////////////////////////////////
/**
 * 工作报告
 * */
//创建工作报告
 export function netCreateWork(data) {
	 return myRequest('daily/createDaily',data)
 }
 //获取 工作  报告
 export function netWorkreportList(data) {
	 return myRequest('daily/getList',data)
 }
 //获取  工作报告  详情
 export function netWorkDetail(data) {
	 return myRequest('daily/getDailyDetail',data)
 }
 //创建工作报告草稿
 export function netCreateStraf(data) {
 	 return myRequest('daily/daily_draft',data)
 }
 //获取  工作报告草稿  详情
 export function netWorkDraftDetail(data) {
 	 return myRequest('daily/getDailyDraftDetail',data)
 }
 //获取工作报告已读和未读列表
 export function netWorkisRead(data) {
	 return myRequest('daily/getDailyRead',data)
 }
 //审批
 //审批名称 列表
 export function netWorkExamineName() {
 	return myRequest('approval/getList')
 }
 
 //获取审批记录列表 
 export function netWorkExamineList(data) {
 	return myRequest('approval/examineApprovalList',data)
 }
 
 //根据审批名称  获取 审批表单
 export function netWorkExamineForm(data) {
 	return myRequest('approval/getFormapproval',data)
 }	
 
 //获取 审批 详情
 export function netWorkExamineDetail(data) {
 	return myRequest('approval/getDetail',data)
 }
 
 //创建 审批 提交
 export function netCreateWorkExamine(data) {
 	return myRequest('approval/addApproval',data)
 }
 
//获取产品 配置 列表
export function netProductConfig(data) {
	return myRequest('product/getPartList',data)
}

//获取待审批数量
export function netPendApprovel(data) {
	return myRequest('message/getExamineInfo',data)
}
//审批通知列表
export function netApprovelTip(data) {
	return myRequest('message/getExamineRecord',data)
}
//获取审批通知  列表
export function netApprovelNotice(data) {
	return myRequest('examine_record/get_examine_list',data)
}

//获取审批流程 	
// type:  contract 合同   receivables  回款   consume 费用   achievement 业绩目标  approval 办公
export function netApprovalProcess(data) {
	return myRequest('staff/getsteplist',data)
}

//审批流程详情 
//type:  contract 合同   receivables  回款    consume 费用   achievement 业绩目标   approval 办公
//relation_id 
export function netApprovalDetail(data) {
	return myRequest('staff/getstepdetail',data)
}

//线索更换负责人
export function netCluesTrans(data) {
	return myRequest('leads/transfer',data)
}

/**
 * 团队操作 接口
 */
//获取团队成员
export function netTeamList(data) {
	return myRequest('setting/team',data)
}
//修改团队成员
export function netTeamEdit(data) {
	return myRequest('setting/editShowStaff',data)
}

//获取业绩分割比例
export function netDistributionType(data) {
	return myRequest('contract/getRatio',data)
}

//获取业绩统计
export function netAchievementStatistics(data) {
	return myRequest('statistics/getAchievementDetail',data)
}
///////////////////////////////////////////////////////////////////////////
//判断是否已经设置
export function netisSetTimeslot() {
	return myRequest('attendance/is_week')
}
//添加时间段
export function netAddTimeSlot(data) {
	return myRequest('attendance/time_add',data)
}
//时间段修改
export function netEditTimeSlot(data) {
	return myRequest('attendance/time_update',data)
}
//时间段列表
export function netTimeSlotList(data) {
	return myRequest('attendance/time_list',data)
}
//时间段详情
export function netTimeSlotDetail(data) {
	return myRequest('attendance/time_detail',data)
}
//时间段删除
export function netDelTimeSlot(data) {
	return myRequest('attendance/time_del',data)
}
///////////////////////////////////////////////////////
//地址添加
export function netAddAddress(data) {
	return myRequest('attendance/address_add',data)
}
//地址详情
export function netAddressDetail(data) {
	return myRequest('attendance/address_detail',data)
}
//地址修改
export function netEditAddress(data) {
	return myRequest('attendance/address_update',data)
}
//地址列表
export function netAddressList(data) {
	return myRequest('attendance/address_list',data)
}
//地址删除
export function netDelAddress(data){
	return myRequest('attendance/address_del',data)
}
////////////////////////////////////////////////////////////
//添加规则
export function netAddRules(data) {
	return myRequest('attendance/rule_add',data)
}
//规则列表
export function netRulesList(data) {
	return myRequest('attendance/rule_list',data)
}
//规则详情
export function netRulesDetail(data) {
	return myRequest('attendance/rule_detail',data)
}
//规则删除
export function netDelRules(data) {
	return myRequest('attendance/rule_del',data)
}
//规则修改
export function netEditRules(data) {
	return myRequest('attendance/rule_update',data)
}
/////////////////////////////////////////////////////////////
//判断是否可以打卡
export function netIsPunch(data) {
	return myRequest('attendance/is_card',data,'POST',false)
}
//正常打卡
export function netPunchClock(data) {
	return myRequest('attendance/card_add',data)
}
//外出打卡
export function netOutClock(data) {
	return myRequest('attendance/other_card',data)
}
//补卡申请
export function netSupplementClock(data) {
	return myRequest('attendance/card_late',data)
}
//获取考情详情
export function netCheckworkDetail(data) {
	return myRequest('attendance/get_statisc',data)
}
//获取打卡统计
export function netClockStatis(data) {
	return myRequest('attendance/statistics',data)
}
//获取考勤月统计
export function netClockMonthStatis(data) {
	return myRequest('attendance/month_statistics',data)
}
//获取 考勤日统计
export function netClockDayStatis(data) {
	return myRequest('attendance/day_statistics',data)
}
//计算请假时长
export function netLeaveDuration(data) {
	return myRequest('attendance/getleavetime',data)
}
//请假
export function netApplyLeave(data) {
	return myRequest('attendance/leave',data)
}
//获取补卡记录
export function netCardList(data) {
	return myRequest('attendance/get_card_late',data)
}
//补卡记录详情
export function netCardDetail(data) {
	return myRequest('attendance/get_card_detail',data)
}
//获取请假记录
export function netLeaveList(data) {
	return myRequest('attendance/get_leave',data)
}
//获取请假记录详情
export function netLeaveDetail(data) {
	return myRequest('attendance/get_leave_detail',data)
}
//获取外勤打卡详情
export function netOutClockDetail(data) {
	return myRequest('attendance/get_attendance_detail',data)
}

/////////////////////////////////////////////////////////////////////
//商机列表
export function netBusinessList(data) {
	return myRequest('business/getList',data)
}
//商机详情
export function netBusinessDetail(data) {
	return myRequest('business/getDetail',data)
}
//增加商机
export function netAddBusiness(data) {
	return myRequest('business/addBusiness',data)
}
//修改商机
export function netEditBusiness(data) {
	return myRequest('business/editBusiness',data)
}
//转移商机
export function netTransBusiness(data) {
	return myRequest('business/batch_change',data)
}
//删除商机
export function netDelBusiness(data) {
	return myRequest('business/delete',data)
}
//客户关联的商机
export function netRelationBusiness(data) {
	return myRequest('business/business_list',data)
}
//选择关联   商机列表
export function netSelectBusinessList(data) {
	return myRequest('business/get_select_list',data)
}
//商机关联的合同
export function netRelationContract(data) {
	return myRequest('business/contract',data)
}
//推进商机 状态
export function netAdvanceBusiness(data) {
	return myRequest('business/business_status',data)
}
//推进商机阶段的  历史
export function netBusinessHistory(data) {
	return myRequest('business/business_history',data)
}






